@@ -24,11 +24,10 @@
 #endif
 #include <linux/serial.h>
 
-#ifndef PORT_16C950
-#define PORT_16C950	10	/* Oxford Semiconductor */
-#endif
+#include "version.h"
 
-#define VERSION_STR "2.15"
+static char version_str[] = "setserial version " SETSERIAL_VERSION ", "
+	SETSERIAL_DATE;
 
 char *progname;
 
@@ -47,21 +46,15 @@ struct serial_type_struct {
 	PORT_16450,	"16450",
 	PORT_16550,	"16550",
 	PORT_16550A,	"16550A",
-#ifdef PORT_CIRRUS
 	PORT_CIRRUS,	"Cirrus",
-#endif
-#ifdef PORT_16650
 	PORT_16650,	"16650",
-#endif
-#ifdef PORT_16650V2
 	PORT_16650V2, 	"16650V2",
-#endif
-#ifdef PORT_16750
 	PORT_16750,	"16750",
-#endif
-#ifdef PORT_16C950
-	PORT_16C950,	"16C950",
-#endif
+	PORT_16C950,	"16950/954",
+	PORT_16C950,	"16950",
+	PORT_16C950,	"16954",
+	PORT_16654,	"16654",
+	PORT_16850,	"16850",
 	PORT_UNKNOWN,	"none",
 	-1,		NULL
 };
@@ -99,6 +92,8 @@ struct flag_type_table {
 	CMD_FLAG,	"spd_normal",	0,		ASYNC_SPD_MASK,	2, 0,
 	CMD_FLAG,	"spd_hi",	ASYNC_SPD_HI, 	ASYNC_SPD_MASK, 0, 0,
 	CMD_FLAG,	"spd_vhi",	ASYNC_SPD_VHI,	ASYNC_SPD_MASK,	0, 0,
+	CMD_FLAG,	"spd_shi",	ASYNC_SPD_SHI,	ASYNC_SPD_MASK,	0, 0,
+	CMD_FLAG,	"spd_warp",	ASYNC_SPD_WARP,	ASYNC_SPD_MASK,	0, 0,
 	CMD_FLAG,	"spd_cust",	ASYNC_SPD_CUST,	ASYNC_SPD_MASK,	0, 0,
 	
 	CMD_FLAG, 	"SAK", 		ASYNC_SAK, 	ASYNC_SAK, 	0, FLAG_CAN_INVERT,
@@ -106,17 +101,11 @@ struct flag_type_table {
 	CMD_FLAG,	"hup_notify",	ASYNC_HUP_NOTIFY, ASYNC_HUP_NOTIFY, 0, FLAG_CAN_INVERT,
 	CMD_FLAG,	"skip_test",	ASYNC_SKIP_TEST,ASYNC_SKIP_TEST,2, FLAG_CAN_INVERT,
 	CMD_FLAG,	"auto_irq",	ASYNC_AUTO_IRQ,	ASYNC_AUTO_IRQ,	2, FLAG_CAN_INVERT,
-#ifdef ASYNC_SPLIT_TERMIOS
 	CMD_FLAG,	"split_termios", ASYNC_SPLIT_TERMIOS, ASYNC_SPLIT_TERMIOS, 2, FLAG_CAN_INVERT,
-#endif
 	CMD_FLAG,	"session_lockout", ASYNC_SESSION_LOCKOUT, ASYNC_SESSION_LOCKOUT, 2, FLAG_CAN_INVERT,
 	CMD_FLAG,	"pgrp_lockout", ASYNC_PGRP_LOCKOUT, ASYNC_PGRP_LOCKOUT, 2, FLAG_CAN_INVERT,
-#ifdef ASYNC_CALLOUT_NOHUP
 	CMD_FLAG,	"callout_nohup", ASYNC_CALLOUT_NOHUP, ASYNC_CALLOUT_NOHUP, 2, FLAG_CAN_INVERT,
-#endif
-#ifdef ASYNC_LOW_LATENCY
 	CMD_FLAG,	"low_latency", ASYNC_LOW_LATENCY, ASYNC_LOW_LATENCY, 0, FLAG_CAN_INVERT,
-#endif /* ASYNC_LOW_LATENCY */
 	CMD_PORT,	"port",		0,		0,		0, FLAG_NEED_ARG,
 	CMD_IRQ,	"irq",		0,		0,		0, FLAG_NEED_ARG,
 	CMD_DIVISOR,	"divisor",	0,		0,		0, FLAG_NEED_ARG,
@@ -124,9 +113,7 @@ struct flag_type_table {
 	CMD_BASE,	"base",		0,		0,		0, FLAG_NEED_ARG,
 	CMD_BASE,	"baud_base",	0,		0,		0, FLAG_NEED_ARG,
 	CMD_DELAY,	"close_delay",	0,		0,		0, FLAG_NEED_ARG,
-#ifdef ASYNC_CLOSING_WAIT_NONE
 	CMD_WAIT,	"closing_wait",	0,		0,		0, FLAG_NEED_ARG,
-#endif
 	CMD_CONFIG,	"autoconfig",	0,		0,		0, 0,
 	CMD_CONFIG,	"autoconfigure",0,		0,		0, 0,
 	CMD_GETMULTI,	"get_multiport",0,		0,		0, 0,
@@ -456,7 +443,6 @@ void get_serial(char *device)
 		printf("\tBaud_base: %d, close_delay: %d, divisor: %d\n",
 		       serinfo.baud_base, serinfo.close_delay,
 		       serinfo.custom_divisor);
-#ifdef ASYNC_CLOSING_WAIT_NONE
 		if (serinfo.closing_wait == ASYNC_CLOSING_WAIT_INF)
 			strcpy(buf1, "infinte");
 		else if (serinfo.closing_wait == ASYNC_CLOSING_WAIT_NONE)
@@ -464,7 +450,6 @@ void get_serial(char *device)
 		else
 			sprintf(buf1, "%d", serinfo.closing_wait);
 		printf("\tclosing_wait: %s\n", buf1);
-#endif
 		print_flags(&serinfo, "\tFlags: ", "");
 		printf("\n\n");
 
@@ -562,7 +547,6 @@ void set_serial(char *device, char ** arg)
 		case CMD_DELAY:
 			new_serinfo.close_delay = atonum(*arg++);
 			break;
-#ifdef ASYNC_CLOSING_WAIT_NONE
 		case CMD_WAIT:
 			if (!strcasecmp(*arg, "infinite"))
 				new_serinfo.closing_wait = ASYNC_CLOSING_WAIT_INF;
@@ -581,7 +565,6 @@ void set_serial(char *device, char ** arg)
 				new_serinfo.closing_wait2 = atonum(*arg);
 			arg++;
 			break;
-#endif
 		case CMD_CONFIG:
 			if (ioctl(fd, TIOCSSERIAL, &new_serinfo) < 0) {
 				perror("Cannot set serial info");
@@ -671,7 +654,7 @@ void do_wild_intr(char *device)
 
 void usage()
 {
-	fprintf(stderr, "setserial Version %s\n\n", VERSION_STR);
+	fprintf(stderr, "%s\n\n", version_str);
 	fprintf(stderr,
 		"usage:\t %s serial-device -abqvVWz [cmd1 [arg]] ... \n", 
 		progname);
@@ -681,17 +664,15 @@ void usage()
 fprintf(stderr, "\t* port\t\tset the I/O port\n");
 	fprintf(stderr, "\t* irq\t\tset the interrupt\n");	
 	fprintf(stderr, "\t* uart\t\tset UART type (none, 8250, 16450, 16550, 16550A,\n");
-	fprintf(stderr, "\t\t\t16650, 16650V2, 16750)\n");
+	fprintf(stderr, "\t\t\t16650, 16650V2, 16750, 16850, 16950, 16954)\n");
 	fprintf(stderr, "\t* baud_base\tset base baud rate (CLOCK_FREQ / 16)\n");
 	fprintf(stderr, "\t* divisor\tset the custom divisor (see spd_custom)\n");
 	fprintf(stderr, "\t* close_delay\tset the amount of time (in 1/100 of a\n");
 	fprintf(stderr, "\t\t\t\tsecond) that DTR should be kept low\n");
 	fprintf(stderr, "\t\t\t\twhile being closed\n");
-#ifdef ASYNC_CLOSING_WAIT_NONE
 	fprintf(stderr, "\t* closing_wait\tset the amount of time (in 1/100 of a\n");
 	fprintf(stderr, "\t\t\t\tsecond) that the serial port should wait for\n");
 	fprintf(stderr, "\t\t\t\tdata to be drained while being closed.\n");
-#endif
 	fprintf(stderr, "\t^ fourport\tconfigure the port as an AST Fourport\n");
 	fprintf(stderr, "\t  autoconfig\tautomatically configure the serial port\n");
 	fprintf(stderr, "\t^ auto_irq\ttry to determine irq during autoconfiguration\n");
@@ -700,20 +681,14 @@ fprintf(stderr, "\t* port\t\tset the I/O port\n");
 	fprintf(stderr, "\t^ sak\t\tset the break key as the Secure Attention Key\n");
 	fprintf(stderr, "\t^ session_lockout Lock out callout port across different sessions\n");
 	fprintf(stderr, "\t^ pgrp_lockout\tLock out callout port across different process groups\n");
-#ifdef ASYNC_CALLOUT_NOHUP
 	fprintf(stderr, "\t^ callout_nohup\tDon't hangup the tty when carrier detect drops\n");
-#endif
 	fprintf(stderr, "\t\t\t\t on the callout device\n");
-#ifdef ASYNC_SPLIT_TERMIOS
 	fprintf(stderr, "\t^ split_termios Use separate termios for callout and dailin lines\n");
-#endif	
 	fprintf(stderr, "\t^ hup_notify\tNotify a process blocked on opening a dial in line\n");
 	fprintf(stderr, "\t\t\t\twhen a process has finished using a callout\n");
 	fprintf(stderr, "\t\t\t\tline by returning EAGAIN to the open.\n");
-#ifdef ASYNC_LOW_LATENCY
 	fprintf(stderr, "\t^ low_latency\tMinimize receive latency at the cost of greater\n");
 	fprintf(stderr, "\t\t\t\tCPU utilization.\n");
-#endif
 	fprintf(stderr, "\t  get_multiport\tDisplay the multiport configuration\n");
 	fprintf(stderr, "\t  set_multiport\tSet the multiport configuration\n");
 	fprintf(stderr, "\n");
@@ -728,6 +703,8 @@ fprintf(stderr, "\t* port\t\tset the I/O port\n");
 	fprintf(stderr, "\n");
 	fprintf(stderr, "\t  spd_hi\tuse 56kb instead of 38.4kb\n");
 	fprintf(stderr, "\t  spd_vhi\tuse 115kb instead of 38.4kb\n");
+	fprintf(stderr, "\t  spd_shi\tuse 230kb instead of 38.4kb\n");
+	fprintf(stderr, "\t  spd_warp\tuse 460kb instead of 38.4kb\n");
 	fprintf(stderr, "\t  spd_cust\tuse the custom divisor to set the speed at 38.4kb\n");
 	fprintf(stderr, "\t\t\t\t(baud rate = baud_base / custom_divisor)\n");
 	fprintf(stderr, "\t  spd_normal\tuse 38.4kb when a buad rate of 38.4kb is selected\n");
@@ -768,7 +745,7 @@ main(int argc, char **argv)
 			verbosity = -1;
 			break;
 		case 'V':
-			fprintf(stderr, "setserial version %s\n", VERSION_STR);
+			fprintf(stderr, "%s\n", version_str);
 			exit(0);
 		case 'W':
 			wild_intr_flag++;
