@@ -5,5 +5,5 @@
  * redistributed under the GNU Public License.
  */
 
-#define SETSERIAL_VERSION "2.16"
-#define SETSERIAL_DATE "8-Mar-99"
+#define SETSERIAL_VERSION "2.17"
+#define SETSERIAL_DATE "27-Jan-2000"
